@@ -35,7 +35,7 @@ class RedisMixin(object):
         :param pattern: pattern
         :return:
         """
-        r = cls.get_redis()
+        r = cls().get_redis()
         if not r:
             raise Exception('redis connection not established')
 
